==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QCloseEvent_shell.cpp <==
#include "QCloseEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QCloseEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCloseEvent")
    QCloseEvent *_ptr = reinterpret_cast<QCloseEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QCloseEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QCloseEvent_shell) ); }

jmethodID QCloseEvent_shell::__shell_javaMethod(int pos) const { return QCloseEvent_shell::__shell()->javaMethod(typeid(QCloseEvent), pos); }

// emitting (writeShellConstructor)
QCloseEvent_shell::QCloseEvent_shell()
    : QCloseEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

QCloseEvent_shell::QCloseEvent_shell(const QCloseEvent& arg__1)
    : QCloseEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell(const QCloseEvent& arg__1)", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

// emitting (writeShellDestructor)
QCloseEvent_shell::~QCloseEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QCloseEvent::~QCloseEvent()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->destructed(typeid(QCloseEvent));
}

void QCloseEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QCloseEvent_shell*>(ptr)->QCloseEvent_shell::__shell()->tryDeleteShell(typeid(QCloseEvent));
}

// emitting Virtual overrides (virtualFunctions)
QCloseEvent* QCloseEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QCloseEvent::clone()const", QCloseEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QCloseEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QCloseEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QCloseEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QCloseEvent_shell::__shell()->warnForMethod("QCloseEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QCloseEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QCloseEvent::clone();
        }
    }else{
        return QCloseEvent::clone();
    }
}

void QCloseEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QCloseEvent::", QCloseEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QCloseEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QCloseEvent_shell::__shell()->warnForMethod("QCloseEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QCloseEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QCloseEvent_access::__qt_assign_cref_QCloseEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QCloseEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCloseEvent>(__jni_env, other0);
    QCloseEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QCloseEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QCloseEvent* __qt_return_value = QCloseEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QCloseEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QCloseEvent()
void __qt_construct_QCloseEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent()")
    Q_UNUSED(__java_arguments)
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QCloseEvent(QCloseEvent)
void __qt_construct_QCloseEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent(QCloseEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QCloseEvent& __qt_arg__1 = qtjambi_cast<const QCloseEvent& >(__jni_env, arg__1);
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QCloseEvent_shell
void __qt_destruct_QCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCloseEvent")
    reinterpret_cast<QCloseEvent_shell*>(ptr)->~QCloseEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCloseEvent::QCloseEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent_0, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCloseEvent::QCloseEvent(QCloseEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent(QCloseEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent_1, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCloseEvent::operator=(QCloseEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_assign_1native_1cref_1QCloseEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCloseEvent::operator=(QCloseEvent)", __qt_this)
        static_cast<QCloseEvent_access*>(__qt_this)->__qt_assign_cref_QCloseEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCloseEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCloseEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QCloseEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QCloseEvent>("QCloseEvent", "io/qt/gui/QCloseEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QCloseEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QCloseEvent, {
        ConstructorInfo(&__qt_construct_QCloseEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCloseEvent_1, "Lio/qt/gui/QCloseEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCloseEvent);
    registerSizeOfShell(typeId, sizeof(QCloseEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QCloseEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QCloseEvent_shell.cpp <==
#include "QCloseEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QCloseEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCloseEvent")
    QCloseEvent *_ptr = reinterpret_cast<QCloseEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QCloseEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QCloseEvent_shell) ); }

jmethodID QCloseEvent_shell::__shell_javaMethod(int pos) const { return QCloseEvent_shell::__shell()->javaMethod(typeid(QCloseEvent), pos); }

// emitting (writeShellConstructor)
QCloseEvent_shell::QCloseEvent_shell()
    : QCloseEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

QCloseEvent_shell::QCloseEvent_shell(const QCloseEvent& arg__1)
    : QCloseEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QCloseEvent::QCloseEvent_shell(const QCloseEvent& arg__1)", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->constructed(typeid(QCloseEvent));
}

// emitting (writeShellDestructor)
QCloseEvent_shell::~QCloseEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QCloseEvent::~QCloseEvent()", QCloseEvent_shell::__shell())
    QCloseEvent_shell::__shell()->destructed(typeid(QCloseEvent));
}

void QCloseEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QCloseEvent_shell*>(ptr)->QCloseEvent_shell::__shell()->tryDeleteShell(typeid(QCloseEvent));
}

// emitting Virtual overrides (virtualFunctions)
QCloseEvent* QCloseEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QCloseEvent::clone()const", QCloseEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QCloseEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QCloseEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QCloseEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QCloseEvent_shell::__shell()->warnForMethod("QCloseEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QCloseEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QCloseEvent::clone();
        }
    }else{
        return QCloseEvent::clone();
    }
}

void QCloseEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QCloseEvent::", QCloseEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QCloseEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QCloseEvent_shell::__shell()->warnForMethod("QCloseEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QCloseEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QCloseEvent_access::__qt_assign_cref_QCloseEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QCloseEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCloseEvent>(__jni_env, other0);
    QCloseEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QCloseEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QCloseEvent* __qt_return_value = QCloseEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QCloseEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QCloseEvent()
void __qt_construct_QCloseEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent()")
    Q_UNUSED(__java_arguments)
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QCloseEvent::QCloseEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCloseEvent(QCloseEvent)
void __qt_construct_QCloseEvent_cref_QCloseEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCloseEvent(QCloseEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QCloseEvent& __qt_arg__1 = qtjambi_cast<const QCloseEvent& >(__jni_env, arg__1);
    QCloseEvent *__qt_this = new(__qtjambi_ptr) QCloseEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCloseEvent::QCloseEvent(QCloseEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_initialize_1native__Lio_qt_gui_QCloseEvent_2Lio_qt_gui_QCloseEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCloseEvent::QCloseEvent(QCloseEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCloseEvent_cref_QCloseEvent, sizeof(QCloseEvent_shell), typeid(QCloseEvent), true, &deleter_QCloseEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCloseEvent_shell
void __qt_destruct_QCloseEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCloseEvent")
    reinterpret_cast<QCloseEvent_shell*>(ptr)->~QCloseEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCloseEvent::operator=(QCloseEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_assign_1native_1cref_1QCloseEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCloseEvent::operator=(QCloseEvent)", __qt_this)
        static_cast<QCloseEvent_access*>(__qt_this)->__qt_assign_cref_QCloseEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCloseEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QCloseEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCloseEvent *__qt_this = QtJambiAPI::objectFromNativeId<QCloseEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCloseEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QCloseEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QCloseEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QCloseEvent>("QCloseEvent", "io/qt/gui/QCloseEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QCloseEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QCloseEvent, {
        ConstructorInfo(&__qt_construct_QCloseEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QCloseEvent_cref_QCloseEvent, "Lio/qt/gui/QCloseEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCloseEvent);
    registerSizeOfShell(typeId, sizeof(QCloseEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QCloseEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
